"""
Django Automated Logging (DAL) is a package with the purpose of
making logging in django automated and easy.

Simple as that. Really.
"""
default_app_config = 'automated_logging.apps.AutomatedloggingConfig'
