# -*- coding: utf-8 -*-
# Generated by Django 1.10.2 on 2018-02-16 09:00
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('automated_logging', '0002_auto_20180215_1540'),
    ]

    operations = [
        migrations.AlterField(
            model_name='modelobject',
            name='value',
            field=models.CharField(max_length=255, null=True),
        ),
    ]
